@@ -1,18 +1,21 @@
 package Evo;
-use strict;
-use warnings;
-use Evo::Manager;
 use Evo::Base -strict;
+use Evo::Manager;
 
-our $VERSION = '0.014';    # VERSION
+use Exporter 'import';
 
-sub asap : prototype(&@) {
-  state $train = Evo::Manager->singleton->build_train;
-  $train->way->add($_) for @_;
-  $train->start unless $train->is_current;
-}
+my @DSL  = qw(dsl_stash dsl_check_stash dsl_call dsl_depth);
+my @FUNC = qw(asap);
+our @EXPORT_OK = (@DSL, @FUNC);
+our %EXPORT_TAGS = (all => \@EXPORT_OK, dsl => \@DSL);
 
-sub dsl_depth : prototype() { Evo::Manager->singleton->dsl_depth; }
+our $VERSION = '0.015';    # VERSION
+
+sub asap : prototype(&@)            { Evo::Manager->singleton->asap(@_) }
+sub dsl_depth : prototype()         { Evo::Manager->singleton->dsl_depth; }
+sub dsl_call : prototype($;@)       { Evo::Manager->singleton->dsl_call(@_); }
+sub dsl_stash : prototype(;$$)      { Evo::Manager->singleton->dsl_stash(@_); }
+sub dsl_check_stash : prototype(;$) { Evo::Manager->singleton->dsl_stash(@_); }
 
 1;
 
@@ -30,30 +33,30 @@ Evo - Perl Evo design pattern
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
   use Evo::Base -strict;
   use Evo;
 
-  # next tick, always nb
-  our $state = 'non blocking';
-  Evo::asap {
-    sub {
-      say $state;
-      local $state = 'blocking?';
-      Evo::asap { say $state };
-      }
-  };
-
   use Evo::Manager;
   my $mngr = Evo::Manager->new;
 
+  # next tick
+  our $state = 'non blocking';
+
+  # always nb
+  Evo::asap {
+    say $state;
+    local $state = 'blocking?';
+    Evo::asap { say $state };
+  };
+
   # dsl
   # prints 1;2;foo
   my @args = (1, 2);
-  my $print = sub(@args) { local $, = ';'; say @args, $mngr->current('foo') };
+  my $print = sub(@args) { local $, = ';'; say @args, $mngr->dsl_stash('foo') };
   $mngr->dsl_call({foo => 'foo'}, @args, $print);
 
   # currying
@@ -100,15 +103,10 @@ version 0.014
 
 =head1 METHODS
 
-=head2 asap
+=head2 asap, dsl_depth, dsl_stash dsl_check_stash dsl_call dsl_depth
 
-Runs a code asap, but not more than in the 1st dsl depth. Used to avoid
-a temporary memory usage in recursion (run out from recursion) without
-modifying a recursive algorithm
-
-=head2 dsl_depth
-
-The depth of current dsl
+Calls corresponding L<Evo::Manager> methods passing a singleton as the first
+argument
 
 =head1 AUTHOR
 
