@@ -11,19 +11,30 @@ sub default_curry ($self) {
   $self->curry_wrappers(Evo::Wrappers::w_dsl_init());
 }
 
+sub asap {
+  my $self = shift;
+  my $in_asap = my $train = $self->{asap};
+  local $self->{asap} = $train = [] unless $in_asap;
+
+  push $train->@*, @_;
+  return if $in_asap;
+
+  shift(@$train)->() while scalar @$train;
+}
+
 sub build_way($self,%args) {
   $args{curry} //= $self->default_curry;
   $self->SUPER::build_way(%args);
 }
 
-# return current, or value by key
+# return dsl_stash, or value by key
 # if not exists, return false without error
-sub check_current($self, $key=undef) {
-  my $cur = $self->singleton->{CURRENT} or return;
+sub dsl_check_stash($self, $key=undef) {
+  my $cur = $self->singleton->{STASH} or return;
   $key ? exists $cur->{$key} : $cur;
 }
 
-sub current { Evo::Util::_current('CURRENT', shift->singleton, @_) }
+sub dsl_stash { Evo::Util::_dsl_stash('STASH', shift->singleton, @_) }
 
 sub _call {
   my ($self, $cb) = (shift, pop);
@@ -33,22 +44,10 @@ sub _call {
 
 sub dsl_depth { $_[0]->{dsl_depth} //= 0 }
 
-# extend current for next cb. shoult die on existing keys
-sub dsl_extend {
-  my ($self, $cb) = (shift, pop);
-  my $extend  = shift // Carp::croak 'provide extend hashref';
-  my @args    = @_;
-  my $current = {$self->current->%*};
-
-  local $self->singleton->{CURRENT} = $current;
-  $self->current($_ => $extend->{$_}) for keys %$extend;
-  $self->_call(sub { $cb->(@args) });
-}
-
 # initialize dsl
 sub dsl_call {
   my ($self, $cb) = (shift, pop);
-  local $self->singleton->{CURRENT} = shift // {};
+  local $self->singleton->{STASH} = shift // {};
   my @args = @_;
 
   $self->_call(sub { $cb->(@args) });
@@ -81,7 +80,7 @@ Evo::Manager - Perl Evo manager
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -93,11 +92,11 @@ version 0.014
   my $train = $mngr->build_train(way => $way);
 
   my $curry = $mngr->curry_wrappers(w_dsl_init);
-  $curry->(sub { say keys $mngr->current->%* })->($mngr->build_train);
+  $curry->(sub { say keys $mngr->dsl_stash->%* })->($mngr->build_train);
 
   my @args = qw(1 2);
   my $stash = {foo => 'bar'};
-  $mngr->dsl_call($stash, @args, sub { say $mngr->current('foo'); say @_ });
+  $mngr->dsl_call($stash, @args, sub { say $mngr->dsl_stash('foo'); say @_ });
 
   # see more example in Evo.pm docs
 
@@ -115,54 +114,38 @@ together with a less typing.
 A default curry function, bassed to L<Evo::Way> instances. Dont't make this
 as an attribute while subclassing, unless you are sure what you want
 
-=head2 check_current
+=head2 dsl_check_stash
 
-  my $context = $mngr->check_current;
-  my $exists  = $mngr->check_current('key');
+  my $context = $mngr->dsl_check_stash;
+  my $exists  = $mngr->dsl_check_stash('key');
 
-Safely check a current context without throwing an extention.
+Safely check a dsl_stash context without throwing an extention.
 
-=head2 current
+=head2 dsl_stash
 
-Work with current context
+Work with dsl_stash context
 
   # get all context
-  my $current = $mngr->current;
+  my $dsl_stash = $mngr->dsl_stash;
 
   # get value by key
-  my $val = $mngr->current('key');
+  my $val = $mngr->dsl_stash('key');
 
   # set value once
-  $mngr->current('new' => 'val')->current('new');
+  $mngr->dsl_stash('new' => 'val')->dsl_stash('new');
 
 Thows an error when is called outside dsl. Throws an error if key doesn't exist
 Throws an error on attempts to override existing key. You can also use
-L</"check_current"> or as hash referrence, but in most
+L</"dsl_check_stash"> or as hash referrence, but in most
 cases if you get an error, you're doing something wrong.
 
 =head2 dsl_call
 
-Invoke a callback with dsl. First argument is L</"current"> context,
+Invoke a callback with dsl. First argument is L</"dsl_stash"> context,
 last is a code referrence, others will be passed as arguments
 
   $mngr->dsl_call({}, 1, 2, sub { });
-  $mngr->dsl_call({foo => 2}, sub { say $mngr->current('foo') });
-
-=head2 dsl_extend (Experimental)
-
-  $mngr->dsl_call(
-    {foo => 2},
-    sub {
-      local $, = '; ';
-      say keys $mngr->current->%*;
-      $mngr->dsl_extend({bar => 3}, sub { say keys $mngr->current->%*; });
-      say keys $mngr->current->%*;
-    }
-  );
-
-Extends current dsl with keys from first argument for invocation of the last
-one. Others will be passed as arguments. You still can'not override existing
-keys. Thows an expection outside dsl
+  $mngr->dsl_call({foo => 2}, sub { say $mngr->dsl_stash('foo') });
 
 =head2 run_wrappers
 
@@ -196,6 +179,20 @@ Singleton - the same instance will be returned for every invocation
   A depth of recurcive L</"dsl_call"> or L</"dsl_extend"> invocations by
   instance. C<0> means we are not in the dsl
 
+=head2 asap
+
+  # change order and flatten a flow
+  $mngr->asap(
+    sub {
+      say 1;
+      $mngr->asap(sub { say 3 });
+    },
+    sub { say 2 }
+  );
+
+Run code as soon as possible but avoid recursions with the "run away from
+recursion"
+
 =head1 ATTENTION
 
 Curry isn't a real currying function, it's a partial function. But I have no
