@@ -2,10 +2,10 @@ package Evo::Train;
 use Evo::Base 'Railway::Train';
 use Evo::Manager;
 
-# always current train
-sub is_current($self) {
-  return unless $self->manager->check_current('train');
-  $self->manager->current('train') == $self;
+# always dsl_stash train
+sub is_dsl_stash($self) {
+  return unless $self->manager->dsl_check_stash('train');
+  $self->manager->dsl_stash('train') == $self;
 }
 
 1;
@@ -24,7 +24,7 @@ Evo::Train - A train, running engine
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -48,9 +48,9 @@ This is a subclass of L<Railway::Train>
 
 =head1 METHODS
 
-=head2 is_current
+=head2 is_dsl_stash
 
-  my $bool = $self->is_current;
+  my $bool = $self->is_dsl_stash;
 
 Returns true if we are in this train, false otherwise
 
