@@ -1,26 +1,26 @@
 package Evo::Util;
 use Evo::Base -strict;
 
-# die outside dsl_call (if current not exists)
+# die outside dsl_call (if dsl_stash not exists)
 # die if trying to get unexisting value by key
 # die if trying to override existing value in the same dsl_call
-sub _current {
+sub _dsl_stash {
   my ($name, $self, $key, $val) = @_;
-  my $current = $self->{$name};
-  $current or Carp::confess 'Using current outside station';
-  return $current unless $key;
+  my $dsl_stash = $self->{$name};
+  $dsl_stash or Carp::confess 'Using dsl_stash outside station';
+  return $dsl_stash unless $key;
 
   # get
   unless ($val) {
-    Carp::confess "Using current with wrong key '$key'"
-      unless exists $current->{$key};
-    return $current->{$key} unless $val;
+    Carp::confess "Using dsl_stash with wrong key '$key'"
+      unless exists $dsl_stash->{$key};
+    return $dsl_stash->{$key} unless $val;
   }
 
   # set, die if already exists
   Carp::confess "Attemt to override existing key '$key'"
-    if exists $current->{$key};
-  $current->{$key} = $val;
+    if exists $dsl_stash->{$key};
+  $dsl_stash->{$key} = $val;
   $self;
 }
 
@@ -103,7 +103,7 @@ Evo::Util
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 DESCRIPTION
 
