@@ -60,7 +60,7 @@ sub handle_station($self, $station) {
   Evo::Util::_guard_on_die { $self->cleanup } sub { $station->($self) };
 }
 
-# leave current station
+# leave dsl_stash station
 sub depart($self) {
   Carp::croak 'start train first' unless defined $self->{index};
   $self->{index}++;
@@ -85,7 +85,7 @@ Railway::Train - a running engine
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -151,7 +151,7 @@ Prepare and run a train. You can provide a callback for L</"done">
 
 =head2 can_run
 
-Check if a way has a stations more than current L</"index">
+Check if a way has a stations more than dsl_stash L</"index">
 
 =head2 finish
 
@@ -168,7 +168,7 @@ Increase index by one. Raises an error if index isn't defined
 
 =head2 get_station
 
-Get current station
+Get dsl_stash station
 
 =head1 AUTHOR
 
